Coverage for .tox/p311/lib/python3.10/site-packages/scicom/run.py: 0%

1"""Run simulations."""

2 import argparse

3

4 parser = argparse.ArgumentParser(

5 prog="Run SciCom Simulations",

6 description="This script starts the server interfaces for the different ABM.",

7 epilog="During the running of this script, the interfaces should be reachable at http://127.0.0.1:8521",

8)

9

10 parser.add_argument(

11 "simulation",

12 choices=[

13 "historicalletters", "knowledgespread",

14 ],

15)

16

17 args = parser.parse_args()

18

19 if args.simulation == "historicalletters":

20 from scicom.historicalletters.server import server

21 server.launch()

22 elif args.simulation == "knowledgespread":

23 from scicom.knowledgespread.server import server

24 server.launch()